==> translate-toolkit-3.4.1-1-any.pkg.tar.xz: usr/lib/python3.9/site-packages/translate/lang/am.py <==
#
# Copyright 2007 Zuza Software Foundation
#
# This file is part of translate.
#
# translate is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# translate is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

"""This module represents the Amharic language.

.. seealso:: http://en.wikipedia.org/wiki/Amharic_language
"""


import re

from translate.lang import common


class am(common.Common):
    """This class represents Amharic."""

    listseperator = "፣ "

    sentenceend = "።!?…"

    sentencere = re.compile(
        r"""(?s)    #make . also match newlines
                            .*?         #anything, but match non-greedy
                            [%s]        #the puntuation for sentence ending
                            \s*         #optional spacing after the puntuation
                            """
        % sentenceend,
        re.VERBOSE,
    )

    puncdict = {
        ".": "።",
        ";": "፤",
        ",": "፣",
    }

    ignoretests = {
        "all": ["simplecaps", "startcaps"],
    }

==> translate-toolkit-3.12.2-3-any.pkg.tar.xz: usr/lib/python3.12/site-packages/translate/lang/am.py <==
#
# Copyright 2007 Zuza Software Foundation
#
# This file is part of translate.
#
# translate is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# translate is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

"""
This module represents the Amharic language.

.. seealso:: :wp:`Amharic_language`
"""


import re

from translate.lang import common


class am(common.Common):
    """This class represents Amharic."""

    listseperator = "፣ "

    sentenceend = "።!?…"

    sentencere = re.compile(
        r"""(?s)    #make . also match newlines
                            .*?         #anything, but match non-greedy
                            [%s]        #the puntuation for sentence ending
                            \s*         #optional spacing after the puntuation
                            """
        % sentenceend,
        re.VERBOSE,
    )

    puncdict = {
        ".": "።",
        ";": "፤",
        ",": "፣",
    }

    ignoretests = {
        "all": ["simplecaps", "startcaps"],
    }
